unit main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    Execute: TButton;
    Stop: TButton;
    Panel2: TPanel;
    Memo1: TMemo;
    Memo2: TMemo;
    Splitter1: TSplitter;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Exec(Text:string);
    procedure ExecuteClick(Sender: TObject);
    procedure StopClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses pascalc, pasfunc;

{$R *.DFM}

var Calc : TPasCalc;


procedure ProcessProc;
begin
  // Perform messages processing
  Application.ProcessMessages;
end;


procedure TForm1.FormCreate(Sender: TObject);
begin
  // Create TPasCalc instance
  Calc := TPasCalc.Create;

  // Register idle procedure (not required)
  Calc.SetProcessProc(@ProcessProc);

  // Register user-defined functions from module pasfunc.pas
  SetFunctions(Calc);
end;


procedure TForm1.FormDestroy(Sender: TObject);
begin
  Calc.Free;
end;


procedure TForm1.Exec(Text:string);
var
  i : integer;
  s : string;
  R : TVar;
  T : TDateTime;
begin
  Memo2.Clear;

  // Reset variable list
  Calc.ClearVars;

  Stop.Enabled := true;
  Execute.Enabled := false;

  T := Now;

  // Execite script
  Calc.Execute(Text);

  T := Now-T;

  Stop.Enabled := false;
  Execute.Enabled := true;

  // Display execution errors (if any)
  if Calc.ErrCode<>0 then
  begin
    Memo2.Lines.Add(Calc.ErrMsg);
    Memo2.Lines.Add(Calc.ErrLine);
    Memo2.Lines.Add('');
  end;

  // Display variables
  for i := 0 to Calc.VarCount-1 do
  begin
    Calc.VarByIndex(i,R);
    s := R.Name+': ';
    if R.Numeric
    then s := s + FloatToStr(R.Num)
    else s := s + ''''+R.Str+'''';
    Memo2.Lines.Add(s);
  end;

  // Display time elapsed
  Memo2.Lines.Add('Time elapsed '+FloatToStr(T*SecsPerDay)+' sec.');
end;

procedure TForm1.ExecuteClick(Sender: TObject);
begin
  Exec(Memo1.Text);
end;

procedure TForm1.StopClick(Sender: TObject);
begin
  // Break execution
  Calc.Stop := true;
end;

end.


